lilypondfiletools.make_floating_time_signature_lilypond_file
============================================================

.. autofunction:: abjad.tools.lilypondfiletools.make_floating_time_signature_lilypond_file.make_floating_time_signature_lilypond_file
